@@ -1016,8 +1016,11 @@ class LegacyMUC(
             item = ans["pubsub"]["items"]["item"]
             item["id"] = self.jid
             return item
-        except (IqError, IqTimeout) as exc:
-            warnings.warn(f"Cannot fetch bookmark: {exc}")
+        except IqTimeout as exc:
+            warnings.warn(f"Cannot fetch bookmark for {self.user_jid}: timeout")
+            return None
+        except IqError as exc:
+            warnings.warn(f"Cannot fetch bookmark for {self.user_jid}: {exc}")
             return None
         except PermissionError:
             warnings.warn(
